@@ -143,7 +143,7 @@ class Worker(object):
         self.output.seek(0, io.SEEK_SET)
         output = self.output.read()
         self.output.close()
-        return output
+        return output.decode("utf8")
 
     def _fail(self, reason):
         self.application.db.update("UPDATE push SET status = ?, output = ?, completed = DATETIME('NOW') WHERE id = ?",
